from datetime import datetime

import streamlit as st
import plotly.express as px
import requests
import pandas as pd


# Configure the page
st.set_page_config(page_title="Sales Prediction Dashboard", layout="wide")

# Title and description
st.title("Sales Prediction Dashboard")
st.markdown("Enter the details below to get quantity predictions")
# Get the current year
current_year = datetime.now().year

# Generate future SEASON options dynamically
future_years = [current_year + i for i in range(10)]  # Next 10 years
seasons = ["FALL", "HOLIDAY", "SPRING", "SUMMER"]
season_options = [f"{season}-{year}" for year in future_years for season in seasons]

st.header("Enter Franchise, Season, and SKU Details")


# Input form
with st.form("prediction_form"):
    franchise_id = st.text_input("Franchise ID", placeholder="Enter Franchise ID (e.g., F001)")
    # season = st.selectbox("Season", ["Summer", "Winter"])
    seasons = ["FALL", "HOLIDAY", "SPRING", "SUMMER"]
    # season_options = [f"{season}-{year}" for year in future_years for season in seasons]
    season = st.selectbox("SEASON", season_options)
    sku = st.text_input("SKU (Optional)", placeholder="Enter SKU (e.g., SKU001)")
    
    submitted = st.form_submit_button("Get Prediction")

if submitted:
    # Prepare the request data
    request_data = {
        "franchise_id": franchise_id,
        "season": season,
        "sku": sku if sku else None
    }

    try:
        # Make API request
        response = requests.post("http://localhost:8000/predict", json=request_data)
        response.raise_for_status()
        result = response.json()

        # Display prediction
        st.header("Prediction Results")
        st.metric("Predicted Quantity", f"{result['predicted_quantity']:.2f}")

        # Visualize data
        if result['has_sku'] and result['predicted_quantity'] > 0:
            # Create pie chart for SKU distribution
            fig = px.pie(
                values=list(result['data']['SKU Distribution'].values()),
                names=list(result['data']['SKU Distribution'].keys()),
                title=f"SKU Distribution for {franchise_id} - {season}"
            )
            st.plotly_chart(fig)
        elif result['predicted_quantity'] > 0:
            # Create table view for all SKUs
            st.subheader("SKU Breakdown")
            df = pd.DataFrame(
                result['data'].items(),
                columns=['SKU', 'Quantity']
            )
            st.dataframe(df)
        else:
            st.warning("No data available for the selected criteria")

    except requests.exceptions.RequestException as e:
        st.error(f"Error connecting to the API: {str(e)}")
    except Exception as e:
        st.error(f"An error occurred: {str(e)}")